'' =================================================================================================
''
''   File....... jm_adc124s021_demo.spin
''   Purpose.... 
''   Author..... Jon "JonnyMac" McPhalen
''               Copyright (c) 2013 Jon McPhalen
''               -- see below for terms of use
''   E-mail..... jon@jonmcphalen.com
''   Started.... 
''   Updated.... 30 MAY 2013
''
'' =================================================================================================


con

  _clkmode = xtal1 + pll16x
  _xinfreq = 5_000_000                                          ' use 5MHz crystal

  CLK_FREQ = ((_clkmode - xtal1) >> 6) * _xinfreq
  MS_001   = CLK_FREQ / 1_000
  US_001   = CLK_FREQ / 1_000_000


con

' Propeller Activity Board Connections

  RX1     = 31                                                  ' programming / terminal
  TX1     = 30
  
  SDA     = 29                                                  ' eeprom / i2c
  SCL     = 28

  R_CH    = 27                                                  ' audio channels
  L_CH    = 26

  SD_CS   = 25                                                  ' microSD connections
  SD_DI   = 24
  SD_CLK  = 23
  SD_DO   = 22

  ADC_CS  = 21                                                  ' adc connections
  ADC_SCL = 20 
  ADC_DO  = 19 
  ADC_DI  = 18 

  SERVO_5 = 17                                                  ' servo headers
  SERVO_4 = 16
  SERVO_3 = 15
  SERVO_2 = 14
  SERVO_1 = 13
  SERVO_0 = 12


con

   #1, HOME, GOTOXY, #8, BKSP, TAB, LF, CLREOL, CLRDN, CR       ' PST formmatting control
  #14, GOTOX, GOTOY, CLS


obj

  adc   : "jm_adc124s021"                                       ' adc driver
  term  : "fullduplexserial64"                                  ' for terminal serial


var


pub main | ch

  adc.start(ADC_CS, ADC_SCL, ADC_DO, ADC_DI)                    ' start adc

  term.start(RX1, TX1, %0000, 115_200)                          ' start FDS for terminal
  pause(10)

  term.tx(CLS)

  repeat
    term.tx(HOME)
    repeat ch from 0 to 3                                       ' loop through channels
      term.tx(ch + "0")                                         ' display channel
      term.str(string(" : "))                                   ' spacer
      term.rjdec(adc.read(ch), 4, " ")                          ' channel value
      term.tx(CR)
    pause(25)

 
con

  { --------------- }
  {                 }
  {   B A S I C S   }
  {                 }
  { --------------- }


pub pause(ms) | t

'' Delay program in milliseconds

  if (ms < 1)                                                   ' delay must be > 0
    return
  else
    t := cnt - 1776                                             ' sync with system counter
    repeat ms                                                   ' run delay
      waitcnt(t += MS_001)
    

pub high(pin)

'' Makes pin output and high

  outa[pin] := 1
  dira[pin] := 1


pub low(pin)

'' Makes pin output and low

  outa[pin] := 0
  dira[pin] := 1


pub toggle(pin)

'' Toggles pin state

  !outa[pin]
  dira[pin] := 1


pub input(pin)

'' Makes pin input and returns current state

  dira[pin] := 0

  return ina[pin]


dat

{{

  Terms of Use: MIT License

  Permission is hereby granted, free of charge, to any person obtaining a copy of this
  software and associated documentation files (the "Software"), to deal in the Software
  without restriction, including without limitation the rights to use, copy, modify,
  merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
  permit persons to whom the Software is furnished to do so, subject to the following
  conditions:

  The above copyright notice and this permission notice shall be included in all copies
  or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MER_CHANTABILITY, FITNESS FOR A
  PARTICULAR PURPOSE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
  CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
  OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

}}